@@ -1,10 +1,8 @@
 from .middleware import mk_jwt_middleware, mk_superadmin_middleware
 from .bottle_plugins import JWTPlugin, ApiKeyAuthPlugin
 from .service import (
-    run_http_service,
-    mk_http_service,
-    run_many_services,
-    run_many_bottle_services,
+    mk_app,
+    run_app,
 )
 from .decorators import (
     Decorator,
@@ -13,6 +11,7 @@ from .decorators import (
     replace_with_params,
     ch_func_to_all_pk,
     mk_flat,
+    mk_handlers,
     add_attrs,
 )
 from .openapi_utils import func_to_openapi_spec
